eq_clean_location: eq_clean_location

Description Usage Arguments Value Examples

View source: R/eq_clean.R

Description

This is a function the converts the location_name from NOAA earthquake data from uppercase to title case and remove the country from location_name. (removes everything up to the last colon character.)

Usage

1

Arguments

adf

a dataframe containing NOAA earthquake data

Value

This function returns a dataframe with location_name column as formated as title case without the country name.

Examples

1
2
3
4
## Not run: 
eq_clean_location(mydata)

## End(Not run)

tcoopermont/eqtools documentation built on May 30, 2019, 7:21 a.m.