Description Usage Arguments Value Examples
This is a function the converts the location_name from NOAA earthquake data from uppercase to title case and remove the country from location_name. (removes everything up to the last colon character.)
1 | eq_clean_location(adf)
|
adf |
a dataframe containing NOAA earthquake data |
This function returns a dataframe with location_name column as formated as title case without the country name.
1 2 3 4 | ## Not run:
eq_clean_location(mydata)
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.